<?php

/*
 * Squelette : plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux.html
 * Date :      Fri, 03 Jul 2020 06:40:15 GMT
 * Compile :   Sat, 11 Jul 2020 03:55:59 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux.html
// Temps de compilation total: 1.275 ms
//

function html_e372a195a6954d4b4b2bd4fcb31beee6($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<'.'?php header(' . _q('HTTP/1.1 503 Service Temporarily Unavailable') . '); ?'.'>' .
'<'.'?php header(' . _q('Status: 503 Service Temporarily Unavailable') . '); ?'.'>' .
'<'.'?php header(' . _q('Retry-After: 7200') . '); ?'.'><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html dir="ltr" lang="fr" xml:lang="fr" xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>' .
_T('entravaux:en_travaux') .
'</title>
<meta name="robots" content="noindex, nofollow" />
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<style type="text/css">
html { font-size: 100%; }
body { background: #fff url(' .
find_in_path('entravaux-bg.gif') .
'); text-align: left; font: 1em/normal Verdana,Geneva,sans-serif; color: #000; }
#minipres { width: 30em; margin: 40px; margin-left: 120px; }
#minipres h1 { font-size: 1.1em; color: #970038; font-weight: bold; }
</style>
</head>
<body>
	<div id="minipres">
		<h1>' .
_T('public|spip|ecrire:info_travaux_titre') .
'</h1>
		' .
interdire_scripts(propre((include_spip('inc/config')?lire_config('entravaux_message',_T('entravaux:info_travaux_texte'),false):''))) .
'
		' .
(($t1 = strval(interdire_scripts(invalideur_session($Cache, ((table_valeur($GLOBALS["visiteur_session"], (string)'id_auteur', null)) ?'' :' ')))))!=='' ?
		($t1 . (	'
		<p class="retour">&#91;<a href="' .
	interdire_scripts(generer_url_public('login_sos', '')) .
	'">' .
	_T('public|spip|ecrire:lien_connecter') .
	'</a>&#93;</p>
		')) :
		'') .
'
		' .
(($t1 = strval(interdire_scripts(invalideur_session($Cache, ((table_valeur($GLOBALS["visiteur_session"], (string)'id_auteur', null)) ?' ' :'')))))!=='' ?
		($t1 . (	'
		<p class="retour">&#91;<a href="' .
	generer_url_ecrire('accueil') .
	'">' .
	_T('public|spip|ecrire:espace_prive') .
	'</a>&#93; &#91;<a href="' .
	executer_balise_dynamique('URL_LOGOUT',
	array(),
	array('plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux.html','html_e372a195a6954d4b4b2bd4fcb31beee6','',4,$GLOBALS['spip_lang'])) .
	'">' .
	_T('public|spip|ecrire:icone_deconnecter') .
	'</a>&#93;</p>
		')) :
		'') .
'
	</div>
</body>
</html>');

	return analyse_resultat_skel('html_e372a195a6954d4b4b2bd4fcb31beee6', $Cache, $page, 'plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux.html');
}
?>