<?php

/*
 * Squelette : ../plugins/menus-22051-v1.7.26/menus/formulaires/editer_menus_entree.html
 * Date :      Fri, 03 Jul 2020 06:40:00 GMT
 * Compile :   Thu, 09 Jul 2020 08:21:22 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/menus-22051-v1.7.26/menus/formulaires/editer_menus_entree.html
// Temps de compilation total: 0.271 ms
//

function html_a63168d51d132c0526bb7887c29d47e8($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div class="formulaire_spip formulaire_editer ' .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'form', null),true))))!=='' ?
		('formulaire_' . $t1) :
		'') .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'form', null),true))))!=='' ?
		(' formulaire_' . $t1 . (	'-' .
	interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'id_menu', null), 'nouveau'),true)))) :
		'') .
'">
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_ok', null))))!=='' ?
		('<p class="reponse_formulaire reponse_formulaire_ok">' . $t1 . '</p>') :
		'') .
'
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_erreur', null))))!=='' ?
		('<p class="reponse_formulaire reponse_formulaire_erreur">' . $t1 . '</p>') :
		'') .
'

	' .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'editable', null),true))))!=='' ?
		($t1 . (	'

	<form method=\'post\' action=\'' .
	interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'action', null),true)) .
	'\' enctype=\'multipart/form-data\'><div>
		
		' .
		'<div>' .
	form_hidden(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'action', null),true))) .
	'<input name=\'formulaire_action\' type=\'hidden\'
		value=\'' . @$Pile[0]['form'] . '\' />' .
	'<input name=\'formulaire_action_args\' type=\'hidden\'
		value=\'' . @$Pile[0]['formulaire_args']. '\' />' .
	(!empty($Pile[0]['_hidden']) ? @$Pile[0]['_hidden'] : '') .
	'</div><ul class="editer-groupe">
			<li class="fieldset">
				<fieldset>
					<h3 class="legend">' .
	_T('menus:formulaire_partie_construction') .
	'</h3>
					<input style="display:none;" type="submit" class="submit" name="enregistrer" value="' .
	_T('public|spip|ecrire:bouton_enregistrer') .
	'" />

					' .
	recuperer_fond( 'formulaires/inc-menus_entrees' , array_merge($Pile[0],array()), array('compil'=>array('../plugins/menus-22051-v1.7.26/menus/formulaires/editer_menus_entree.html','html_a63168d51d132c0526bb7887c29d47e8','',17,$GLOBALS['spip_lang'])), _request('connect')) .
	'</fieldset>
			</li>
		</ul>
	</div></form>

	')) :
		'') .
'
</div>

<script type="text/javascript">
	(function($){
		$(\'.entree .actions\').hide();
		$(\'.entree .ligne\')
			.hover(
				function(){
					$(this).find(\'.actions\').show();
				},
				function(){
					$(this).find(\'.actions\').hide();
				}
			);
	})(jQuery);
</script>
');

	return analyse_resultat_skel('html_a63168d51d132c0526bb7887c29d47e8', $Cache, $page, '../plugins/menus-22051-v1.7.26/menus/formulaires/editer_menus_entree.html');
}
?>