<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor_p2-v2.html
 * Date :      Fri, 03 Jul 2020 11:43:54 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:54 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor_p2-v2.html
// Temps de compilation total: 0.084 ms
//

function html_e7dc02f6dafc5855b17a72f6432239c2($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
(($t1 = strval(find_in_path('css/ckeditor.css')))!=='' ?
		('<link rel=\'stylesheet\' href=\'' . $t1 . '\' type=\'text/css\' />') :
		'') .
'
<style type=\'text/css\'>
	li.saisie_case_image, li.saisie_case { clear:none; display:block ; float:left ; padding-left:10px ; }
</style>
');

	return analyse_resultat_skel('html_e7dc02f6dafc5855b17a72f6432239c2', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor_p2-v2.html');
}
?>