<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/contenu/configurer_ckeditor.html
 * Date :      Fri, 03 Jul 2020 11:43:53 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/contenu/configurer_ckeditor.html
// Temps de compilation total: 2.745 ms
//

function html_1e2333373036223d0a271a16383eaba8($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
invalideur_session($Cache, sinon_interdire_acces(((function_exists("autoriser")||include_spip("inc/autoriser"))&&autoriser('configurer', '_ckeditor')?" ":""))) .
'
<h1 class="grostitre">' .
_T('ckeditor:ckeditor_titre') .
'</h1>

' .
barre_onglets('configurer_ckeditor','configurer_ckeditor') .
'

<div class="ajax">
	' .
executer_balise_dynamique('FORMULAIRE_CONFIGURER_CKEDITOR',
	array(),
	array('../plugins/ckeditor-spip-plugin/prive/squelettes/contenu/configurer_ckeditor.html','html_1e2333373036223d0a271a16383eaba8','',7,$GLOBALS['spip_lang'])) .
'
</div>
');

	return analyse_resultat_skel('html_1e2333373036223d0a271a16383eaba8', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/contenu/configurer_ckeditor.html');
}
?>