<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/formulaires/configurer_ckeditor_p2.html
 * Date :      Fri, 03 Jul 2020 11:43:36 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:55 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/formulaires/configurer_ckeditor_p2.html
// Temps de compilation total: 0.412 ms
//

function html_41cbc380a686235e351847505c6517b0($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div class="formulaire_spip formulaire_configurer formulaire_' .
interdire_scripts(@$Pile[0]['form']) .
'">

	<h3 class="titrem">' .
_T('ckeditor:ckeditor_p2_titre') .
'</h3>

	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_ok', null))))!=='' ?
		('<p class="reponse_formulaire reponse_formulaire_ok">' . $t1 . '</p>') :
		'') .
'
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_erreur', null))))!=='' ?
		('<p class="reponse_formulaire reponse_formulaire_erreur">' . $t1 . '</p>') :
		'') .
'

	<form method="post" action="' .
interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'action', null),true)) .
'">
	<div>
		' .
	'<div>' .
	form_hidden(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'action', null),true))) .
	'<input name=\'formulaire_action\' type=\'hidden\'
		value=\'' . @$Pile[0]['form'] . '\' />' .
	'<input name=\'formulaire_action_args\' type=\'hidden\'
		value=\'' . @$Pile[0]['formulaire_args']. '\' />' .
	(!empty($Pile[0]['_hidden']) ? @$Pile[0]['_hidden'] : '') .
	'</div><ul>
		' .
recuperer_fond( 'inclure/generer_saisies' , array_merge($Pile[0],array('saisies' => interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'cke_saisies_p2', null),true)) )), array('compil'=>array('../plugins/ckeditor-spip-plugin/formulaires/configurer_ckeditor_p2.html','html_41cbc380a686235e351847505c6517b0','',11,$GLOBALS['spip_lang'])), _request('connect')) .
'</ul>
		<p class="boutons"><span class="image_loading">&nbsp;</span>
			<input type="submit" class="submit" name="_cfg_delete" value="' .
_T('ckeditor:reinitialiser') .
'" />
			<input type="submit" class="submit" name="_cfg_ok" value="' .
_T('public|spip|ecrire:bouton_enregistrer') .
'" />
		</p>
	</div>
	</form>
</div>
');

	return analyse_resultat_skel('html_41cbc380a686235e351847505c6517b0', $Cache, $page, '../plugins/ckeditor-spip-plugin/formulaires/configurer_ckeditor_p2.html');
}
?>