<?php

/*
 * Squelette : ../plugins/auto/saisies/v3.41.3/saisies/explication.html
 * Date :      Thu, 25 Jun 2020 04:48:00 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:40 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/auto/saisies/v3.41.3/saisies/explication.html
// Temps de compilation total: 0.448 ms
//

function html_bbcdc55c6260612e0a7e21fc317cda80($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<' .
interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'saisies_base_conteneur', null), ((($a = 'div') OR (is_string($a) AND strlen($a))) ? $a : 'li')),true)) .
' class="editer pleine_largeur editer_explication' .
(($t1 = strval(interdire_scripts(saisie_nom2classe(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true)))))!=='' ?
		(' explication_' . $t1) :
		'') .
(($t1 = strval(interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'conteneur_class', null), interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'li_class', null),true))),true))))!=='' ?
		(' ' . $t1) :
		'') .
(($t1 = strval(interdire_scripts(saisie_type2classe(entites_html(table_valeur(@$Pile[0], (string)'type_saisie', null),true)))))!=='' ?
		(' ' . $t1) :
		'') .
'"' .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'id_saisie', null),true))))!=='' ?
		(' data-id="' . $t1 . '"') :
		'') .
(($t1 = strval(interdire_scripts(saisies_afficher_si_js(table_valeur(@$Pile[0], (string)'afficher_si', null),interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'_saisies', null),true))))))!=='' ?
		(' data-afficher_si="' . $t1 . '"') :
		'') .
'>
	' .
interdire_scripts(table_valeur(@$Pile[0], (string)'inserer_debut', null)) .
'<div class="explication">
		' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'titre', null))))!=='' ?
		('<strong class="explication_titre">' . $t1 . '</strong>') :
		'') .
'
		' .
(($t1 = strval(interdire_scripts(saisies_liens_ouvrants(propre(table_valeur(@$Pile[0], (string)'texte', null))))))!=='' ?
		('<div class="explication_texte">' . $t1 . '</div>') :
		'') .
'
	</div>
	' .
interdire_scripts(table_valeur(@$Pile[0], (string)'inserer_fin', null)) .
'</' .
interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'saisies_base_conteneur', null), ((($a = 'div') OR (is_string($a) AND strlen($a))) ? $a : 'li')),true)) .
'>
' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'masquer', null),true)) ?' ' :''))))!=='' ?
		($t1 . (	'
' .
	vide($Pile['vars'][$_zzz=(string)'selector'] = (($t3 = strval(interdire_scripts(saisie_nom2classe(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true)))))!=='' ?
				('.explication_' . $t3) :
				'')) .
	'
<script>
	function masquer(){
		$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' .explication_texte").' .
	(defined('_SAISIES_AFFICHER_SI_JS_HIDE')?constant('_SAISIES_AFFICHER_SI_JS_HIDE'):'') .
	';
		$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' button").text(\'' .
	_T('saisies:afficher') .
	'\');
	};
	function afficher(){
		$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' .explication_texte").' .
	(defined('_SAISIES_AFFICHER_SI_JS_SHOW')?constant('_SAISIES_AFFICHER_SI_JS_SHOW'):'') .
	';
		$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' button").text(\'' .
	_T('saisies:masquer') .
	'\');
	};
	function basculer(){
		if (est_masque == true) {
			est_masque = false;
			afficher();
		} else {
			est_masque = true;
			masquer();
		}
	};

	est_masque = true;
	$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' .explication_texte").css(\'display\',\'none\');
	$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' .explication_titre").append("<span class=\'boutons\'><button type=\'button\'>' .
	_T('saisies:afficher') .
	'</button></span>");
	$("' .
	table_valeur($Pile["vars"], (string)'selector', null) .
	' .explication_titre button").click(function(){basculer();});
</script>
')) :
		'') .
'

');

	return analyse_resultat_skel('html_bbcdc55c6260612e0a7e21fc317cda80', $Cache, $page, '../plugins/auto/saisies/v3.41.3/saisies/explication.html');
}
?>