<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor-v2.html
 * Date :      Fri, 03 Jul 2020 11:43:54 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor-v2.html
// Temps de compilation total: 0.067 ms
//

function html_9e2d6e48c43f27e0179b9e715003ee61($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
(($t1 = strval(find_in_path('css/ckeditor.css')))!=='' ?
		('<link rel=\'stylesheet\' href=\'' . $t1 . '\' type=\'text/css\' />') :
		'') .
'
<style type=\'text/css\'>
	.formulaire_spip li.editer_devtools,
	.formulaire_spip li.editer_ignoreversion,
	.formulaire_spip li.editer_startspellcheck
	{
		padding : 0px 15px 0px 50px ;
	}

	.formulaire_spip li.editer_spellchecklang,
	.formulaire_spip li.editer_apercu,
	.formulaire_spip li.editer_taille,
	.formulaire_spip li.editer_skin,
	.formulaire_spip li.editer_editmode
	{
		padding-left : 250px ;
	}

	.formulaire_spip li.editer_spellchecklang label,
	.formulaire_spip li.editer_apercu label,
	.formulaire_spip li.editer_taille label,
	.formulaire_spip li.editer_skin label,
	.formulaire_spip li.editer_editmode label
	{
		width : 220px ;
		margin-left : -230px ;
	}
</style>
');

	return analyse_resultat_skel('html_9e2d6e48c43f27e0179b9e715003ee61', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor-v2.html');
}
?>