<?php

/*
 * Squelette : ../prive/squelettes/ajax.html
 * Date :      Sun, 21 Jun 2020 17:08:04 GMT
 * Compile :   Thu, 16 Jul 2020 07:53:07 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../prive/squelettes/ajax.html
// Temps de compilation total: 0.344 ms
//

function html_46befb415ff823b0a5220515deb31856($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'
' .
vide($Pile['vars'][$_zzz=(string)'zajax'] = replace(_request('var_zajax'),'\\W','')) .

'<'.'?php echo recuperer_fond( ' . argumenter_squelette((	'prive/squelettes/' .
	concat(table_valeur($Pile["vars"], (string)'zajax', null),'/',interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'type-page', null),true))))) . ', array_merge('.var_export($Pile[0],1).',array(\'espace_prive\' => ' . argumenter_squelette('1') . ',
	\'lang\' => ' . argumenter_squelette($GLOBALS["spip_lang"]) . ')), array("compil"=>array(\'../prive/squelettes/ajax.html\',\'html_46befb415ff823b0a5220515deb31856\',\'\',3,$GLOBALS[\'spip_lang\']),\'ajax\' => ($v=( ' . argumenter_squelette(table_valeur($Pile["vars"], (string)'zajax', null)) . '))?$v:true), _request("connect"));
?'.'>');

	return analyse_resultat_skel('html_46befb415ff823b0a5220515deb31856', $Cache, $page, '../prive/squelettes/ajax.html');
}
?>