<?php

/*
 * Squelette : squelettes-dist/identifiants.html
 * Date :      Sun, 21 Jun 2020 17:08:48 GMT
 * Compile :   Sat, 02 May 2026 20:30:30 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette squelettes-dist/identifiants.html
// Temps de compilation total: 0.973 ms
//

function html_a01deee88c2a7979f51419b8fdcb6514($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<'.'?php header("X-Spip-Cache: 0"); ?'.'>'.'<'.'?php header("Cache-Control: no-cache, must-revalidate"); ?'.'><'.'?php header("Pragma: no-cache"); ?'.'>' .
'<'.'?php header(' . _q((	'Content-Type: text/html' .
	(($t2 = strval(interdire_scripts($GLOBALS['meta']['charset'])))!=='' ?
			('; charset=' . $t2) :
			''))) . '); ?'.'>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="' .
spip_htmlentities(@$Pile[0]['lang'] ? @$Pile[0]['lang'] : $GLOBALS['spip_lang']) .
'" lang="' .
spip_htmlentities(@$Pile[0]['lang'] ? @$Pile[0]['lang'] : $GLOBALS['spip_lang']) .
'" dir="' .
lang_dir(@$Pile[0]['lang'], 'ltr','rtl') .
'">
<head>
	<title>' .
_T('public|spip|ecrire:pass_vousinscrire') .
' - ' .
interdire_scripts(textebrut(typo($GLOBALS['meta']['nom_site'], "TYPO", $connect, $Pile[0]))) .
'</title>
	<meta http-equiv="Content-Type" content="text/html; charset=' .
interdire_scripts($GLOBALS['meta']['charset']) .
'" />
	<meta name="viewport" content="width=device-width" />
	<link rel="stylesheet" href="' .
direction_css(find_in_theme('reset.css')) .
'" type="text/css" />
	<link rel="stylesheet" href="' .
direction_css(find_in_theme('clear.css')) .
'" type="text/css" />
	<link rel="stylesheet" href="' .
direction_css(find_in_theme('minipres.css')) .
'" type="text/css" />
	<meta name="robots" content="none" />
	<meta name="generator" content="SPIP' .
(($t1 = strval(spip_version()))!=='' ?
		(' ' . $t1) :
		'') .
'" />
</head>
<body>
<div id=\'minipres\'>
	<h1>' .
interdire_scripts(typo($GLOBALS['meta']['nom_site'], "TYPO", $connect, $Pile[0])) .
'</h1>
	' .
executer_balise_dynamique('FORMULAIRE_INSCRIPTION',
	array(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'mode', null),true)),interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'id_rubrique', null),true))),
	array('squelettes-dist/identifiants.html','html_a01deee88c2a7979f51419b8fdcb6514','',18,$GLOBALS['spip_lang'])) .
'<div class="quitter_fenetre">
		<script type=\'text/javascript\'>
		/*<![CDATA[*/
			document.write("<a href=\'")
			document.write((window.opener) ? "javascript:close()" : "./")
			document.write("\' title=\'' .
_T('public|spip|ecrire:pass_quitter_fenetre') .
'\'>' .
_T('public|spip|ecrire:pass_quitter_fenetre') .
'<" + "/a>");
			document.getElementById(\'oubli\').focus()
		/*]]>*/
		</script>
		<noscript>
			<a href=\'./\' title=\'' .
_T('public|spip|ecrire:pass_retour_public') .
'\'>' .
_T('public|spip|ecrire:pass_retour_public') .
'</a>
		</noscript>
	</div>
</div><!--#minipres-->
</body>
</html>');

	return analyse_resultat_skel('html_a01deee88c2a7979f51419b8fdcb6514', $Cache, $page, 'squelettes-dist/identifiants.html');
}
?>