<?php

/*
 * Squelette : ../prive/squelettes/navigation/auteur_edit.html
 * Date :      Sun, 21 Jun 2020 17:08:21 GMT
 * Compile :   Thu, 09 Jul 2020 07:11:59 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../prive/squelettes/navigation/auteur_edit.html
// Temps de compilation total: 0.029 ms
//

function html_49803520de3b762584f49bb0c4c28813($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = '';

	return analyse_resultat_skel('html_49803520de3b762584f49bb0c4c28813', $Cache, $page, '../prive/squelettes/navigation/auteur_edit.html');
}
?>