<?php

/*
 * Squelette : ../plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux_notice_ecrire.html
 * Date :      Fri, 03 Jul 2020 06:40:15 GMT
 * Compile :   Sat, 04 Jul 2020 06:04:12 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux_notice_ecrire.html
// Temps de compilation total: 0.111 ms
//

function html_0e290d933eee3c7f82bc28840fc0bc81($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
boite_ouvrir('', 'notice') .
'<p>' .
_T('entravaux:info_maintenance_en_cours') .
'</p>
	' .
(($t1 = strval(invalideur_session($Cache, ((function_exists("autoriser")||include_spip("inc/autoriser"))&&autoriser('entravaux')?" ":""))))!=='' ?
		($t1 . (	'
	<p class="action"><a href="' .
	generer_url_ecrire('configurer_entravaux') .
	'">' .
	_T('entravaux:texte_lien_publier') .
	'</a></p>
	')) :
		'') .
'
' .
boite_fermer());

	return analyse_resultat_skel('html_0e290d933eee3c7f82bc28840fc0bc81', $Cache, $page, '../plugins/en_travaux-90326-v3.2.4/en_travaux/inclure/entravaux_notice_ecrire.html');
}
?>