<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor.html
 * Date :      Fri, 03 Jul 2020 11:43:55 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor.html
// Temps de compilation total: 0.080 ms
//

function html_a0e191400d36d7034af0b006d490a078($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'
' .
recuperer_fond( 'prive/squelettes/inclure/menu-navigation' , array_merge($Pile[0],array('menu' => 'menu_configuration' ,
	'bloc' => 'navigation' )), array('compil'=>array('../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor.html','html_a0e191400d36d7034af0b006d490a078','',2,$GLOBALS['spip_lang'])), _request('connect')));

	return analyse_resultat_skel('html_a0e191400d36d7034af0b006d490a078', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor.html');
}
?>