<?php

/*
 * Squelette : ../plugins/en_travaux-90326-v3.2.4/en_travaux/prive/squelettes/contenu/configurer_entravaux.html
 * Date :      Fri, 03 Jul 2020 06:40:19 GMT
 * Compile :   Thu, 09 Jul 2020 06:52:41 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/en_travaux-90326-v3.2.4/en_travaux/prive/squelettes/contenu/configurer_entravaux.html
// Temps de compilation total: 3.639 ms
//

function html_c38659b0bf3c42145ea9f180856bd704($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
invalideur_session($Cache, sinon_interdire_acces(((function_exists("autoriser")||include_spip("inc/autoriser"))&&autoriser('entravaux')?" ":""))) .
'
<h1 class="grostitre">' .
_T('entravaux:en_travaux') .
'</h1>
<div class="ajax">
	' .
executer_balise_dynamique('FORMULAIRE_CONFIGURER_ENTRAVAUX',
	array(),
	array('../plugins/en_travaux-90326-v3.2.4/en_travaux/prive/squelettes/contenu/configurer_entravaux.html','html_c38659b0bf3c42145ea9f180856bd704','',4,$GLOBALS['spip_lang'])) .
'
</div>
');

	return analyse_resultat_skel('html_c38659b0bf3c42145ea9f180856bd704', $Cache, $page, '../plugins/en_travaux-90326-v3.2.4/en_travaux/prive/squelettes/contenu/configurer_entravaux.html');
}
?>