<?php

/*
 * Squelette : plugins/menus-22051-v1.7.26/menus/inclure/barre-nav.html
 * Date :      Fri, 03 Jul 2020 06:40:03 GMT
 * Compile :   Thu, 27 Jul 2023 09:10:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette plugins/menus-22051-v1.7.26/menus/inclure/barre-nav.html
// Temps de compilation total: 0.097 ms
//

function html_8108ecc4dd4214660a448a1860932429($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div class="menu-conteneur navbar-inner">
' .
recuperer_fond( 'inclure/menu' , array_merge($Pile[0],array('identifiant' => 'barrenav' )), array('compil'=>array('plugins/menus-22051-v1.7.26/menus/inclure/barre-nav.html','html_8108ecc4dd4214660a448a1860932429','',2,$GLOBALS['spip_lang'])), _request('connect')) .
'</div>
');

	return analyse_resultat_skel('html_8108ecc4dd4214660a448a1860932429', $Cache, $page, 'plugins/menus-22051-v1.7.26/menus/inclure/barre-nav.html');
}
?>