<?php

/*
 * Squelette : ../plugins/en_travaux-90326-v3.2.4/en_travaux/formulaires/configurer_entravaux.html
 * Date :      Fri, 03 Jul 2020 06:40:15 GMT
 * Compile :   Thu, 09 Jul 2020 06:52:41 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/en_travaux-90326-v3.2.4/en_travaux/formulaires/configurer_entravaux.html
// Temps de compilation total: 0.487 ms
//

function html_4b97a57d17c130d7b82b2ffd0cc6252a($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'id_auteur', null),true)) ?' ' :''))))!=='' ?
		($t1 . (	'
<div id=\'entravauxnotice\'>
' .
	boite_ouvrir('', 'notice') .
	'<p>' .
	_T('entravaux:info_maintenance_en_cours') .
	'</p>
' .
	boite_fermer() .
	'
</div>
<script type="text/javascript">jQuery(function(){jQuery(\'#contenu h1:first\').after(jQuery("#entravauxnotice").remove());})</script>
')) :
		'') .
'
' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'id_auteur', null),true)) ?'' :' '))))!=='' ?
		($t1 . '
<script type="text/javascript">jQuery(function(){jQuery("#entravauxnotice").remove();})</script>
') :
		'') .
'

<div class="formulaire_spip formulaire_configurer formulaire_' .
interdire_scripts(@$Pile[0]['form']) .
'">
	<h3 class="titrem">' .
_T('entravaux:en_travaux') .
'</h3>
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_erreur', null))))!=='' ?
		('<p class=\'reponse_formulaire reponse_formulaire_erreur\'>' . $t1 . '</p>') :
		'') .
'
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'message_ok', null))))!=='' ?
		('<p class="reponse_formulaire reponse_formulaire_ok">' . $t1 . '</p>') :
		'') .
'

	<p class="explication">' .
_T('entravaux:info_message') .
'</p>
	<form method="post" action="' .
interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'action', null),true)) .
'"><div>
		<input type="hidden" name="_meta_casier" value="" />
		<input type="hidden" name="_meta_prefixe" value="entravaux" />
		' .
	'<div>' .
	form_hidden('SELF') .
	'<input name=\'formulaire_action\' type=\'hidden\'
		value=\'' . @$Pile[0]['form'] . '\' />' .
	'<input name=\'formulaire_action_args\' type=\'hidden\'
		value=\'' . @$Pile[0]['formulaire_args']. '\' />' .
	(!empty($Pile[0]['_hidden']) ? @$Pile[0]['_hidden'] : '') .
	'</div><ul class="editer-groupe">
			<li class="editer editer_accesferme pleine_largeur">
				<div class="choix">
					<input type="checkbox" name="accesferme"' .
(($t1 = strval(interdire_scripts((entites_html(table_valeur(@$Pile[0], (string)'accesferme', null),true) ? 'checked="checked"':''))))!=='' ?
		(' ' . $t1) :
		'') .
' id="accesferme" value="1"
																																																				onchange="if ($(this).is(\':checked\')) {$(\'.maintenance_oui\').show(\'fast\'); $(\'.maintenance_non\').hide(\'fast\');} else {$(\'.maintenance_oui\').hide(\'fast\'); $(\'.maintenance_non\').show(\'fast\');}" />
					<label for="accesferme">' .
_T('entravaux:activer_message') .
'</label>
				</div>
			</li>
			<li class="editer editer_autoriser_travaux' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'accesferme', null),true)) ?'' :' '))))!=='' ?
		($t1 . 'none') :
		'') .
' maintenance_oui">
				<label>' .
_T('entravaux:autoriser_travaux') .
'</label>
				<div class="choix">
					<input type="radio" name="autoriser_travaux"' .
(($t1 = strval(interdire_scripts(((((((entites_html(table_valeur(@$Pile[0], (string)'autoriser_travaux', null),true) == 'webmestre')) OR (interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'autoriser_travaux', null),true)) ?'' :' ')))) ?' ' :'')) ?' ' :''))))!=='' ?
		(' ' . $t1 . 'checked="checked"') :
		'') .
' id="autoriser_travaux_webmestre" value="webmestre" />
					<label for="autoriser_travaux_webmestre">' .
Ucfirst(_T('public|spip|ecrire:statut_webmestre')) .
'</label>
				</div>
				<div class="choix">
					<input type="radio" name="autoriser_travaux"' .
(($t1 = strval(interdire_scripts((((entites_html(table_valeur(@$Pile[0], (string)'autoriser_travaux', null),true) == '0minirezo')) ?' ' :''))))!=='' ?
		(' ' . $t1 . 'checked="checked"') :
		'') .
' id="autoriser_travaux_admin" value="0minirezo" />
					<label for="autoriser_travaux_admin">' .
Ucfirst(_T('public|spip|ecrire:info_statut_administrateur')) .
'</label>
				</div>
				<div class="choix">
					<input type="radio" name="autoriser_travaux"' .
(($t1 = strval(interdire_scripts((((entites_html(table_valeur(@$Pile[0], (string)'autoriser_travaux', null),true) == '1comite')) ?' ' :''))))!=='' ?
		(' ' . $t1 . 'checked="checked"') :
		'') .
' id="autoriser_travaux_auteur" value="1comite" />
					<label for="autoriser_travaux_auteur">' .
Ucfirst(_T('public|spip|ecrire:info_statut_redacteur')) .
'</label>
				</div>
			</li>
			<li class="editer editer_message pleine_largeur' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'accesferme', null),true)) ?'' :' '))))!=='' ?
		($t1 . 'none') :
		'') .
' maintenance_oui">
				<label for=\'message\'>' .
_T('entravaux:message_temporaire') .
'</label>
				<textarea name=\'message\' id=\'message\'>' .
interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'message', null), _T('entravaux:info_travaux_texte')),true)) .
'
				</textarea>
				<p class="explication"><strong>' .
_T('entravaux:info_disallow_robot') .
'</strong></p>
			</li>
			<li class="editer editer_disallow_robots pleine_largeur' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'accesferme', null),true)) ?' ' :''))))!=='' ?
		($t1 . 'none') :
		'') .
' maintenance_non">
				<div class="choix">
					<input type="checkbox" name="disallow_robots"' .
(($t1 = strval(interdire_scripts((entites_html(table_valeur(@$Pile[0], (string)'disallow_robots', null),true) ? 'checked="checked"':''))))!=='' ?
		(' ' . $t1) :
		'') .
' id="disallow_robots" />
					<label for="disallow_robots">' .
_T('entravaux:label_disallow_robots') .
'</label>
				</div>
			</li>
		</ul>
		<p class="boutons">
			<input type="submit" value="' .
_T('public|spip|ecrire:bouton_enregistrer') .
'" class="submit" />
		</p>
	</div></form>
</div>
');

	return analyse_resultat_skel('html_4b97a57d17c130d7b82b2ffd0cc6252a', $Cache, $page, '../plugins/en_travaux-90326-v3.2.4/en_travaux/formulaires/configurer_entravaux.html');
}
?>