<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/style_prive_plugin_ckeditor.html
 * Date :      Fri, 03 Jul 2020 11:43:40 GMT
 * Compile :   Sat, 04 Jul 2020 05:55:41 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/style_prive_plugin_ckeditor.html
// Temps de compilation total: 0.059 ms
//

function html_832c9556dc665e9108d415e4bb30b767($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'
' .
'<'.'?php header(' . _q('Content-Type: text/css') . '); ?'.'>#wysiwyg ul,
#wysiwyg ul.spip {
  margin-left: 2.5em;
  list-style: circle;
}
#wysiwyg ol,
#wysiwyg ol.spip {
  margin-left: 2.5em;
  list-style-type: decimal;
}');

	return analyse_resultat_skel('html_832c9556dc665e9108d415e4bb30b767', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/style_prive_plugin_ckeditor.html');
}
?>