<?php

/*
 * Squelette : ../plugins/auto/saisies/v3.41.3/inclure/generer_saisies.html
 * Date :      Thu, 25 Jun 2020 04:48:00 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   _contenu
 */ 

function BOUCLE_contenuhtml_447ebd1b9ae63ea517c1c29a0f96997b(&$Cache, &$Pile, &$doublons, &$Numrows, $SP) {

	static $command = array();
	static $connect;
	$command['connect'] = $connect = '';
	$command['source'] = array(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'saisies', null),true)));
	$command['sourcemode'] = 'table';
	if (!isset($command['table'])) {
		$command['table'] = '';
		$command['id'] = '_contenu';
		$command['from'] = array();
		$command['type'] = array();
		$command['groupby'] = array();
		$command['select'] = array(".valeur");
		$command['orderby'] = array();
		$command['where'] = 
			array();
		$command['join'] = array();
		$command['limit'] = '';
		$command['having'] = 
			array();
	}
	if (defined("_BOUCLE_PROFILER")) $timer = time()+(float)microtime();
	$t0 = "";
	// REQUETE
	$iter = IterFactory::create(
		"DATA",
		$command,
		array('../plugins/auto/saisies/v3.41.3/inclure/generer_saisies.html','html_447ebd1b9ae63ea517c1c29a0f96997b','_contenu',39,$GLOBALS['spip_lang'])
	);
	if (!$iter->err()) {
	$SP++;
	// RESULTATS
	while ($Pile[$SP]=$iter->fetch()) {

		$t0 .= (
'
' .
((array_key_exists('saisie',interdire_scripts($Pile[$SP]['valeur'])))  ?
		(' ' . (	'
' .
	saisies_generer_html($Pile[$SP]['valeur'],interdire_scripts(((($a = entites_html(table_valeur(@$Pile[0], (string)'_env', null),true)) OR (is_string($a) AND strlen($a))) ? $a : unserialize(@serialize($Pile[0]))))) .
	'
')) :
		'') .
'
');
	}
	$iter->free();
	}
	if (defined("_BOUCLE_PROFILER")
	AND 1000*($timer = (time()+(float)microtime())-$timer) > _BOUCLE_PROFILER)
		spip_log(intval(1000*$timer)."ms BOUCLE_contenu @ ../plugins/auto/saisies/v3.41.3/inclure/generer_saisies.html","profiler"._LOG_AVERTISSEMENT);
	return $t0;
}

//
// Fonction principale du squelette ../plugins/auto/saisies/v3.41.3/inclure/generer_saisies.html
// Temps de compilation total: 13.093 ms
//

function html_447ebd1b9ae63ea517c1c29a0f96997b($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'

' .
BOUCLE_contenuhtml_447ebd1b9ae63ea517c1c29a0f96997b($Cache, $Pile, $doublons, $Numrows, $SP) .
'


' .
(($t1 = strval(interdire_scripts((((((entites_html(table_valeur(@$Pile[0], (string)'from_fieldset', null),true)) ?'' :' ')) AND (interdire_scripts(saisies_afficher_si(entites_html(table_valeur(@$Pile[0], (string)'saisies', null),true))))) ?' ' :''))))!=='' ?
		($t1 . (	'
	<script>
		function afficher_si_show(src) {
			src.' .
	interdire_scripts(eval('return '.'_SAISIES_AFFICHER_SI_JS_SHOW'.';')) .
	';
		}
		function afficher_si_hide(src) {
			src.' .
	interdire_scripts(eval('return '.'_SAISIES_AFFICHER_SI_JS_HIDE'.';')) .
	';
		}
	</script>
	' .
	(($t2 = strval(timestamp(find_in_path('javascript/afficher_si.js'))))!=='' ?
			('<script src=\'' . $t2 . '\'></script>') :
			''))) :
		'') .
'
');

	return analyse_resultat_skel('html_447ebd1b9ae63ea517c1c29a0f96997b', $Cache, $page, '../plugins/auto/saisies/v3.41.3/inclure/generer_saisies.html');
}
?>